diff options
| author | KunoiSayami <[email protected]> | 2023-05-01 20:08:57 +0800 |
|---|---|---|
| committer | KunoiSayami <[email protected]> | 2023-05-01 20:08:57 +0800 |
| commit | 58e87dbf5f1ec6905de68d52e23a2a6f4823af44 (patch) | |
| tree | 8d1b0bbd80efa7faf269bb733e163d963692122b /expt_0425.cu | |
| parent | 6f6359c6d9f1a05b509b0509762b77df127ebe37 (diff) | |
fix: expt 0425 will work from now on
Signed-off-by: KunoiSayami <[email protected]>
Diffstat (limited to 'expt_0425.cu')
| -rw-r--r-- | expt_0425.cu | 9 |
1 files changed, 6 insertions, 3 deletions
diff --git a/expt_0425.cu b/expt_0425.cu index 1a8c4e0..6f506ed 100644 --- a/expt_0425.cu +++ b/expt_0425.cu @@ -213,11 +213,14 @@ int main() { initSample<<<1, 1>>>(cudaSample, cudaPopulation); cudaDeviceSynchronize(); - run_kernel(test_size); initCustomSample<<<1, 1>>>(); cudaDeviceSynchronize(); + // check_items<<<1, 1>>>(); + // cudaDeviceSynchronize(); + run_kernel(test_size); + key_type *cudaNormalSample = nullptr; cudaMalloc(&cudaNormalSample, sizeof(key_type) * SAMPLE_LENGTH); cudaMemcpy(cudaNormalSample, le_sample_vector.data(), @@ -225,8 +228,8 @@ int main() { initNormalStorage<<<1, 1>>>(cudaNormalSample); cudaDeviceSynchronize(); - check_items<<<1, 1>>>(); - cudaDeviceSynchronize(); + // check_items<<<1, 1>>>(); + // cudaDeviceSynchronize(); run_kernel(test_size, 0); |
